actionsbox — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »

# actionsbox

Actions box

class `camelot.view.controls.actionsbox.` `ActionsBox`(gui_context, parent)

  A box containing actions to be applied to a view

  Parameters: | gui_context – a `camelot.admin.action.base.GuiContext` object parent – a `PyQt4.QtGui.QWidget` object

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »

Comments
blog comments powered by Disqus